package com.app.ui.adapter

import android.content.Intent
import android.graphics.BitmapFactory
import android.support.v4.app.FragmentManager
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.RelativeLayout
import android.widget.TextView
import com.app.R
import com.app.YYApplication
import com.app.api.InterfaceUrlConstants
import com.app.api.RequestApiData
import com.app.constants.KeyConstants
import com.app.model.UserBase
import com.app.model.VideoGirlUser
import com.app.model.request.SponsorVideoRequest
import com.app.model.response.SponsorVideoResponse
import com.app.ui.activity.HomeActivity
import com.app.ui.activity.IndividualitySpaceActivity
import com.app.ui.fragment.OnLineVoiceFragment
import com.app.util.Tools
import com.app.util.cache.YYPreferences
import com.app.widget.avi.AVLoadingIndicatorView
import com.app.widget.dialog.SceneSelectionDialog
import com.sp.util.YYPreferenceSP
import com.yy.util.image.VolleyUtil
import com.yy.util.net.NewHttpResponeCallBack
import com.yy.util.string.StringUtils
import java.util.*

public class OnLineVoiceFragmentAdapter(var activity: HomeActivity, var fragmentManager: FragmentManager?) : RecyclerView.Adapter<OnLineVoiceFragmentAdapter.OnLineVoiceFragmentViewHolder>() {

    private var mData: ArrayList<VideoGirlUser>? = null
    private val defaultLeftBitmap = BitmapFactory.decodeResource(
            YYApplication.getInstance().resources,
            R.drawable.user_icon_default)

    override fun onCreateViewHolder(viewGroup: ViewGroup, i: Int): OnLineVoiceFragmentViewHolder {
        return OnLineVoiceFragmentViewHolder(LayoutInflater.from(YYApplication.getInstance())
                .inflate(R.layout.online_voice_item_layout, viewGroup, false))
    }

    override fun onBindViewHolder(onLinePersonFragmentViewHolder: OnLineVoiceFragmentViewHolder, i: Int) {

        val videoGirlUser = mData!![i]
        val userBase = videoGirlUser.userBase
        val voiceDescribe = videoGirlUser.voiceDescribe
        val nickName = userBase.nickName
        val image = userBase.image
        if (!StringUtils.isEmpty(nickName)) {
            onLinePersonFragmentViewHolder.userName.text = getNickName(nickName)
        }
        // 描述
        onLinePersonFragmentViewHolder.userMonologue.text = '"'+voiceDescribe+'"'
        if (image != null) {
            val imageUrl = image.thumbnailUrl
            if (!StringUtils.isEmpty(imageUrl)) {
                YYApplication.getInstance().imageLoader.get(imageUrl,
                        VolleyUtil.getImageListener(onLinePersonFragmentViewHolder.userPhoto, defaultLeftBitmap, defaultLeftBitmap),
                        onLinePersonFragmentViewHolder.userPhoto.measuredWidth, onLinePersonFragmentViewHolder.userPhoto.measuredHeight, true)
            }
        }

        onLinePersonFragmentViewHolder.userAge.text = StringBuffer().append(userBase.age).append("岁")
        val stringBuffer = StringBuffer()
        if (!StringUtils.isEmpty(userBase.height)) {
            stringBuffer.append(userBase.height).append("cm")
        }

        if (!StringUtils.isEmpty(userBase.weight)) {
            stringBuffer.append("/").append((Integer.valueOf(userBase.weight) / 2)).append("kg")
        }
        onLinePersonFragmentViewHolder.userHeightWeight.text = stringBuffer


        onLinePersonFragmentViewHolder.userVoiceLeft.invalidate()
        onLinePersonFragmentViewHolder.userVoiceLeft.show()

        onLinePersonFragmentViewHolder.userVoiceRight.invalidate()
        onLinePersonFragmentViewHolder.userVoiceRight.show()


        onLinePersonFragmentViewHolder.userVoiceLy.setTag(R.id.tag_obj, userBase)
        onLinePersonFragmentViewHolder.userVoiceLy.setOnClickListener {
            val tag = it.getTag(R.id.tag_obj) as UserBase
            videoInvitation(tag, if (tag.showVoice == 1) SponsorVideoRequest.SRC_RECOMMENT_VOICE_CHAT else SponsorVideoRequest.SRC_RECOMMENT_VIDEO_CHAT)
        }

        onLinePersonFragmentViewHolder.userInfoLy.setTag(R.id.tag_obj, userBase)
        onLinePersonFragmentViewHolder.userInfoLy.setOnClickListener {
            val tag = it.getTag(R.id.tag_obj) as UserBase
            val intent = Intent(YYApplication.getInstance(), IndividualitySpaceActivity::class.java)
            intent.putExtra(KeyConstants.KEY_USER, tag)
            intent.putExtra(KeyConstants.KEY_FROM, OnLineVoiceFragment::class.java.simpleName)
            activity.startActivity(intent)
        }

        onLinePersonFragmentViewHolder.userPhoto.setTag(R.id.tag_obj, userBase)
        onLinePersonFragmentViewHolder.userPhoto.setOnClickListener {
            val tag = it.getTag(R.id.tag_obj) as UserBase
            val intent = Intent(YYApplication.getInstance(), IndividualitySpaceActivity::class.java)
            intent.putExtra(KeyConstants.KEY_USER, tag)
            intent.putExtra(KeyConstants.KEY_FROM, OnLineVoiceFragment::class.java.simpleName)
            activity.startActivity(intent)
        }

    }

    private fun getNickName(nickName: String?): String {
        var nickName: String? = nickName ?: return ""
        if (nickName!!.length > 5) {
            nickName = nickName.substring(0, 5) + "..."
        }
        return nickName
    }


    override fun getItemCount(): Int {
        return if (mData != null) mData!!.size else 0
    }

    fun setData(mUserDatas: ArrayList<VideoGirlUser>) {
        this.mData = mUserDatas
    }

    fun clearData() {
        if (mData != null) {
            mData!!.clear()
        }
    }


    /**
     * 邀请
     * @param userBase
     */
    fun videoInvitation(userBase: UserBase, src: Int) {
        if (YYPreferences.getInstance().getBoolean(YYPreferences.TAG_DEFAUT_SETTING, false) || src == SponsorVideoRequest.SRC_RECOMMENT_VOICE_CHAT) {// 读取默认设置状态
            var isShowFace = false
            val configInfo = YYApplication.getInstance().configInfo
            if (configInfo != null) {
                val otherCfg = configInfo.otherCfg
                if (otherCfg != null) {
                    if (otherCfg.isLeakingFacee == 1) {
                        isShowFace = true
                    }
                }
            }
            loadVideoPlugin(isShowFace, userBase, src)
        } else if (fragmentManager != null) {
            val dialog = SceneSelectionDialog().newInstance()
            dialog.show(fragmentManager, "dialog")
            dialog.setOnFinishListener { isShowFace, isDefautItme ->
                val configInfo = YYApplication.getInstance().configInfo
                if (configInfo != null) {
                    val otherCfg = configInfo.otherCfg
                    if (otherCfg != null) {
                        otherCfg.isLeakingFacee = if (isShowFace) 1 else 0
                        configInfo.otherCfg = otherCfg
                    }
                }
                YYPreferences.getInstance().putBoolean(YYPreferences.TAG_DEFAUT_SETTING, isDefautItme)
                loadVideoPlugin(isShowFace, userBase, src)
            }
        }
    }

    /**
     * 加载插件
     * @param isShowFace 是否露脸
     * *
     * @param userBase
     */
    private fun loadVideoPlugin(isShowFace: Boolean, userBase: UserBase?, src: Int) {

        if (userBase == null || activity == null) {
            return
        }

        val type = if (!Tools.isAvailable(YYApplication.getInstance(), YYApplication.getInstance().VIDEO_APP_PACKAGE_NAME)) 1 else 0
        val request = SponsorVideoRequest(userBase.id, YYPreferences.getInstance().userId, if (isShowFace) 1 else 0, src, type)
        RequestApiData.getInstance().sponsorVideo(request, SponsorVideoResponse::class.java, object : NewHttpResponeCallBack {
            override fun onResponeStart(apiName: String) {
                if (InterfaceUrlConstants.URL_SPONSORVIDEO == apiName) {
                    activity.showLoadingDialog("正在邀请...")
                }
            }

            override fun onLoading(apiName: String, count: Long, current: Long) {

            }

            override fun onSuccess(apiName: String, `object`: Any) {
                if (InterfaceUrlConstants.URL_SPONSORVIDEO == apiName) {
                    if (`object` is SponsorVideoResponse) {
                        val response = `object`
                        val state = response.state
                        YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_STATE, state)
                        if (state == 0 || state == 5) {// 可以连通
                            val usableTime = response.usableTime
                            val videoId = response.videoId
                            val noPwdState = response.noPwdState
                            val continueBuyUrl = response.continueBuyUrl
                            YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_ID, videoId)

                            val url = response.url
                            YYPreferenceSP.getInstance().putString(KeyConstants.KEY_VIDEO_STATE_URL, if (state == 5) url else "")

                            if (userBase != null) {
                                val image = userBase.image
                                var imgUrl = ""
                                if (image != null) {
                                    imgUrl = image.imageUrl
                                }
                                YYApplication.getInstance().startVideoApp(
                                        YYPreferences.getInstance().userId,
                                        userBase.id,
                                        userBase.nickName,
                                        imgUrl,
                                        YYPreferences.getInstance().gender,
                                        usableTime,
                                        isShowFace,
                                        0, 0, noPwdState, continueBuyUrl,
                                        if (activity != null) activity.supportFragmentManager else null)

                            }
                        } else if (state == 6) {
                            val usableTime = response.usableTime
                            val noPwdState = response.noPwdState
                            val continueBuyUrl = response.continueBuyUrl
                            val videoId = response.videoId
                            YYPreferenceSP.getInstance().putInt(KeyConstants.KEY_VIDEO_ID, videoId)

                            if (userBase != null) {
                                val image = userBase.image
                                var imgUrl = ""
                                if (image != null) {
                                    imgUrl = image.imageUrl
                                }
                                YYApplication.getInstance().startVoiceApp(
                                        YYPreferences.getInstance().userId,
                                        userBase.id,
                                        userBase.nickName,
                                        imgUrl,
                                        YYPreferences.getInstance().gender,
                                        usableTime,
                                        0,
                                        noPwdState,
                                        continueBuyUrl,
                                        if (activity != null) activity.supportFragmentManager else null
                                )
                            }

                        } else if (state == 1) {// 跳付费页面
                            val url = response.url
                            activity.showWebViewActivity(url,"会员服务")
                        } else if (state == 2) {// 占线
                            val msg = response.msg
                            Tools.showToast(msg, 3000)
                        } else if (state == 3) {// 占线
                            val msg = response.msg
                            Tools.showToast(msg, 3000)
                        }

                        if (state != 1) {
                            activity.dismissLoadingDialog()
                        }
                    }
                }
            }

            override fun onFailure(apiName: String, t: Throwable?, errorNo: Int, strMsg: String?) {
                Tools.showToast(strMsg)
                activity.dismissLoadingDialog()
            }
        })
    }


    inner class OnLineVoiceFragmentViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {

        var userPhoto: ImageView

        var userVoiceLeft: AVLoadingIndicatorView
        var userVoiceRight: AVLoadingIndicatorView

        var userName: TextView
        var userAge: TextView
        var userHeightWeight: TextView
        var userMonologue: TextView
        var userVoiceLy: RelativeLayout
        var userInfoLy: RelativeLayout

        init {
            userPhoto = itemView.findViewById(R.id.id_user_photo)

            userVoiceLeft = itemView.findViewById(R.id.id_voice_left)
            userVoiceRight = itemView.findViewById(R.id.id_voice_right)

            userName = itemView.findViewById(R.id.id_user_name)
            userAge = itemView.findViewById(R.id.id_user_age)
            userHeightWeight = itemView.findViewById(R.id.id_user_height_weight)
            userMonologue = itemView.findViewById(R.id.id_user_monologue)
            userVoiceLy = itemView.findViewById(R.id.id_voice_ly)
            userInfoLy = itemView.findViewById(R.id.id_user_info_ly)
        }
    }

}
