package com.app.ui.fragment

import android.content.Intent
import android.graphics.Rect
import android.os.Bundle
import android.support.v7.widget.RecyclerView
import android.support.v7.widget.StaggeredGridLayoutManager
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.app.R
import com.app.YYApplication
import com.app.api.InterfaceUrlConstants
import com.app.api.RequestApiData
import com.app.constants.KeyConstants
import com.app.model.NearbyUser
import com.app.model.User
import com.app.model.Yuanfen
import com.app.model.request.GetNearbyUserRequest
import com.app.model.request.GetYuanfenRequest
import com.app.model.response.GetNearbyUserResponse
import com.app.model.response.GetYuanfenResponse
import com.app.ui.activity.IndividualitySpaceActivity
import com.app.ui.adapter.OnLinePersonFragmentAdapter
import com.app.util.Tools
import com.github.jdsjlzx.recyclerview.LRecyclerView
import com.github.jdsjlzx.recyclerview.LRecyclerViewAdapter
import com.github.jdsjlzx.recyclerview.ProgressStyle
import com.yy.ui.fragment.MyFragment
import com.yy.util.LogUtils
import com.yy.util.net.NewHttpResponeCallBack
import java.util.*


/**
 * 在线的人
 */

class OnLinePersonFragment : MyFragment(), NewHttpResponeCallBack {

    private var mRootView: View? = null
    private var mLRecyclerView: LRecyclerView? = null
    // 加载网络页数
    private var loadPageNum = 1
    private var mLRecyclerViewAdapter: LRecyclerViewAdapter? = null
    private var mOnLinePersonFragmentAdapter: OnLinePersonFragmentAdapter? = null
    private val mUserDatas = ArrayList<NearbyUser>()

    override fun onVisible(isInit: Boolean) {

    }


    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        return inflater.inflate(R.layout.online_person_fragment_layout, null)
    }


    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        mRootView = view
        initView()
    }

    private fun initView() {

        mLRecyclerView = mRootView!!.findViewById(R.id.id_lr_list)
        mOnLinePersonFragmentAdapter = OnLinePersonFragmentAdapter(context)
        mOnLinePersonFragmentAdapter!!.setData(mUserDatas)
        mLRecyclerViewAdapter = LRecyclerViewAdapter(mOnLinePersonFragmentAdapter)
        val staggeredGridLayoutManager = StaggeredGridLayoutManager(2, StaggeredGridLayoutManager.VERTICAL)
        mLRecyclerView!!.layoutManager = staggeredGridLayoutManager
        mLRecyclerView!!.adapter = mLRecyclerViewAdapter
        staggeredGridLayoutManager.gapStrategy = StaggeredGridLayoutManager.GAP_HANDLING_NONE
        mLRecyclerView!!.setRefreshProgressStyle(ProgressStyle.BallPulseSync)
        mLRecyclerView!!.setLoadingMoreProgressStyle(ProgressStyle.BallPulse)
        mLRecyclerView!!.addItemDecoration(object : RecyclerView.ItemDecoration() {
            override fun getItemOffsets(outRect: Rect, view: View, parent: RecyclerView, state: RecyclerView.State?) {
                super.getItemOffsets(outRect, view, parent, state)
                val childPosition = parent.getChildPosition(view)

                if (childPosition % 2 == 0) {
                    outRect.left = Tools.dp2px(12f)
                }

                if (childPosition > 3) {
                    outRect.top = Tools.dp2px(12f)
                }
            }
        })

        mLRecyclerView!!.setOnRefreshListener {
            loadPageNum = 0
            mOnLinePersonFragmentAdapter!!.clearData()
            mLRecyclerViewAdapter!!.notifyDataSetChanged()
            loadYuanFenData()
        }

        mLRecyclerView!!.setOnNetWorkErrorListener { loadYuanFenData() }

        mLRecyclerViewAdapter!!.setOnItemClickListener { view, position ->
            if (position < mUserDatas.size) {
                val yuanfen = mUserDatas[position]
                val userBase = yuanfen.userBase
                val intent = Intent(YYApplication.getInstance(), IndividualitySpaceActivity::class.java)
                intent.putExtra(KeyConstants.KEY_USER, userBase)
                intent.putExtra(KeyConstants.KEY_FROM, OnLinePersonFragment::class.java.simpleName)
                startActivity(intent)
            }
        }

        mLRecyclerView!!.forceToRefresh()
    }


    /**
     * 加载缘分数据
     */
    private fun loadYuanFenData() {
        RequestApiData.getInstance().getNearbyUser(GetNearbyUserRequest(YYApplication.getInstance().uploadLocation), GetNearbyUserResponse::class.java, this)
    }

    override fun onResponeStart(apiName: String) {

    }

    override fun onLoading(apiName: String, count: Long, current: Long) {

    }

    override fun onSuccess(apiName: String, `object`: Any) {

        if (InterfaceUrlConstants.URL_GETNEARBYUSER == apiName) {
            if (`object` is GetNearbyUserResponse) {

                val listYuanfen = `object`.listUser

                if (listYuanfen != null && listYuanfen.size > 0) {
                    mUserDatas.addAll(listYuanfen)

                }
            }

            mLRecyclerView!!.refreshComplete(loadPageNum)
            mLRecyclerViewAdapter!!.notifyDataSetChanged()
        }

    }

    override fun onFailure(apiName: String, t: Throwable, errorNo: Int, strMsg: String) {
        if (InterfaceUrlConstants.URL_GETYUANFEN == apiName) {
            mLRecyclerView!!.refreshComplete(loadPageNum)
            mLRecyclerViewAdapter!!.notifyDataSetChanged()
        }
    }


    override fun onDestroyView() {
        super.onDestroyView()
    }

    companion object {
        // 初始缘分数据，首次进入或者下来刷新时使用
        val initSize = 100
    }
}
